<?php 

	/**
	 * Kundengruppen Modul
	 */
	class wpsg_mod_customergroup extends wpsg_mod_basic 
	{
		
		var $id = 3090;		
		var $lizenz = 1;
		var $version = "4.1.8";
		var $hilfeURL = 'http://wpshopgermany.maennchen1.de/?p=13706';
		
		var $customerGroupPerPage = 1;// 25;
		var $free = false;
				
		/**
		 * Costructor
		 */
		public function __construct()
		{
			
			parent::__construct();
			
			$this->name = __('Kundengruppen', 'wpsg');
			$this->group = __('Sonstiges', 'wpsg');
			$this->desc = __('Ist dieses Modul aktiv, so lassen sich die Kunden in Kundengruppen verwalten. Mit den entsprechenden Modul "Rabatt" ist es möglich einen Rabatt je Kundengruppe zu definieren.', 'wpsg');
						
			$this->customerGroupPerPage = $this->shop->get_option('wpsg_mod_kundenverwaltung_group_perpage');
		} // public function __construct()		
		 
		public function install()
		{
			
			require_once(WPSG_PATH_WP.'/wp-admin/includes/upgrade.php');
			
			/** Kundentabelle erweitern */
			$sql = "CREATE TABLE ".WPSG_TBL_KU." (		   		
				group_id INT(11) NOT NULL	   		
		   	) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;";
			 
			dbDelta($sql);
			
			/** Kundengruppentabelle anlegen */
			$sql = "CREATE TABLE ".WPSG_TBL_KG." (
   				id mediumint(9) NOT NULL AUTO_INCREMENT,
   				name VARCHAR(255) NOT NULL,
   				calculation INT(11) DEFAULT '-1' NOT NULL,
   				PRIMARY KEY  (id)
   			) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;";
				
			dbDelta($sql);
						
		} // public function install()
		
		public function init()
		{
				
			// Modell einbinden
			require_once(WPSG_PATH_MOD.'mod_customergroup/wpsg_customergroup.php');
			
		} // public function init()
		
		public function admin_setcapabilities() {
		
			$this->render(WPSG_PATH_VIEW.'/mods/mod_customergroup/admin_setcapabilities.phtml');
		
		} // public function admin_setcapabilities()
		
		public function wpsg_add_pages($default_page)
		{

			add_submenu_page($default_page, __('Kundengruppenverwaltung', 'wpsg'), __('Kundengruppen', 'wpsg'), 'wpsg_customergroup', 'wpsg-Customergroup', array($this, 'be_dispatch'));
				
		} // public function wpsg_add_pages()
		
		public function settings_edit()
		{
			
			$this->shop->view['arCustomergroup'] = wpsg_array_merge(array('0' => __('Unzugeordnet', 'wpsg')), $this->db->fetchAssocField("
				SELECT
					KG.`id`, CONCAT(KG.`name`, ' (ID:', KG.`id`, ')') AS `name`
				FROM
					`".WPSG_TBL_KG."` AS KG
				ORDER BY
					KG.`name` ASC
			", "id", "name"));
			
			$this->shop->render(WPSG_PATH_VIEW.'mods/mod_customergroup/settings_edit.phtml');
			
		} // public function settings_edit()
		
		public function settings_save()
		{

		    $this->shop->update_option('wpsg_mod_kundenverwaltung_group_perpage', $_REQUEST['wpsg_mod_kundenverwaltung_group_perpage'], false, false, WPSG_SANITIZE_TEXTFIELD);
		    $this->shop->update_option('wpsg_page_mod_kundenverwaltung_group_checkout', $_REQUEST['wpsg_page_mod_kundenverwaltung_group_checkout'], false, false, WPSG_SANITIZE_INT);
		    $this->shop->update_option('wpsg_page_mod_kundenverwaltung_group_register', $_REQUEST['wpsg_page_mod_kundenverwaltung_group_register'], false, false, WPSG_SANITIZE_INT);
							
		} // public function settings_save()
				
		/* Modulfunktionen */

        /**
         * Gibt einen Array mit [id] => Titel der Kundengruppen zurück
         */
        public function getCustomerGroupArray() {
            
            return $this->db->fetchAssocField("
                SELECT
                    `id`, `name`
                FROM 
                    `".WPSG_TBL_KG."`
            ", "id", "name");
            
        } // public function getCustomerGroupArray()
        
		public function be_dispatch()
		{
				
			if (wpsg_isSizedString($_REQUEST['action'], 'add'))
			{
					
				$this->addAction();
					
			}
			else if (wpsg_isSizedString($_REQUEST['action'], 'edit'))
			{
		
				$this->editAction();
		
			}
			else if (wpsg_isSizedString($_REQUEST['action'], 'save'))
			{
					
				$this->saveAction();
					
			}
			else if (wpsg_isSizedString($_REQUEST['action'], 'del'))
			{
		
				$this->delAction();
		
			}
			else
			{
					
				$this->indexAction();
					
			}
				
		} // public function be_dispatch()
		 
		/**
		 * Soll eine Kundengruppe bearbeiten
		 */
		public function editAction()
		{
				
			if (!wpsg_isSizedInt($_REQUEST['edit_id'])) throw new \wpsg\Exception(__('Beim bearbeiten einer Kundengruppe wurde keine ID übergeben', 'wpsg'));
				
			$this->shop->view['data'] = new wpsg_customergroup();
			$this->shop->view['data']->load($_REQUEST['edit_id']);
			$this->shop->view['edit_id'] = $_REQUEST['edit_id'];
			$this->shop->view['mode'] = 'edit';
				
			$this->shop->render(WPSG_PATH_VIEW.'mods/mod_customergroup/addedit.phtml');
				
		} // public function editAction()
		
		/**
		 * Soll eine Kundengruppe löschen
		 */
		public function delAction()
		{
				
			$bOK = wpsg_customergroup::delete($_REQUEST['edit_id']);
				
			if ($bOK !== true) $this->shop->addBackendError(__('Kundengruppe konnte nicht erfolgreich gelöscht werden', 'wpsg'));
			else $this->shop->addBackendMessage(__('Kundengruppe wurde erfolgreich gelöscht', 'wpsg'));
				
			$this->shop->redirect(WPSG_URL_WP.'wp-admin/admin.php?page=wpsg-Customergroup');
		
		} // public function delAction()
		
		/**
		 * Generiert das Formular zum Anlegen einer neuen Kundengruppe
		 */
		public function addAction()
		{
				
			$this->shop->view['mode'] = 'add';
			$this->shop->view['edit_id'] = 0;
			$this->shop->view['data'] = false;
				
			$this->shop->render(WPSG_PATH_VIEW.'/mods/mod_customergroup/addedit.phtml');
				
		} // public function addAction()
		
		/**
		 * Speichert eine Kundengruppe im Backend
		 */
		public function saveAction()
		{

			if(isset($_REQUEST['edit_id'])) $_REQUEST['edit_id'] = wpsg_sinput("key", $_REQUEST['edit_id']);

			if (wpsg_isSizedInt($_REQUEST['edit_id']))
			{
					
				// Update
				$this->db->UpdateQuery(WPSG_TBL_KG, array(
						'name' => wpsg_q(wpsg_sinput("text_field", $_REQUEST['wpsg_mod_kundenverwaltung']['name'])),
						'calculation' => wpsg_q($_REQUEST['wpsg_mod_kundenverwaltung']['calculation'])
				), " `id` = '".wpsg_q(wpsg_sinput("key", $_REQUEST['edit_id']))."' ");
					
				$this->shop->addBackendMessage(__('Kundengruppe erfolgreich gespeichert', 'wpsg'));
					
			}
			else
			{
					
				// Insert
				$_REQUEST['edit_id'] = $this->db->ImportQuery(WPSG_TBL_KG, array(
						'name' => wpsg_q(wpsg_sinput("text_field", $_REQUEST['wpsg_mod_kundenverwaltung']['name'])),
						'calculation' => wpsg_q(wpsg_sinput("key", $_REQUEST['wpsg_mod_kundenverwaltung']['calculation']))
				));
					
				$this->shop->addBackendMessage(__('Kundengruppe erfolgreich angelegt', 'wpsg'));
					
			}
				
			$this->shop->callMods('customergroup_save', array(&$_REQUEST['edit_id']));
		
			if (isset($_REQUEST['submit_index']))
			{
					
				$this->shop->redirect(WPSG_URL_WP.'wp-admin/admin.php?page=wpsg-Customergroup');
					
			}
			else
			{
					
				$this->shop->redirect(WPSG_URL_WP.'wp-admin/admin.php?page=wpsg-Customergroup&action=edit&edit_id='.$_REQUEST['edit_id']);
					
			}
				
		} // public function saveAction()
		
		/**
		 * Generiert die Übersicht der Kundengruppen im Backend
		 */
		public function indexAction()
		{

			$nPerPage = $this->customerGroupPerPage;
			if ($nPerPage <= 0) $nPerPage = 10;

			$this->shop->view['hasFilter'] = false;
			$this->shop->view['arFilter'] = array(
				'order' => 'cdate',
				'ascdesc' => 'ASC',
				'status' => '0',
				'page' => '1'
			);

			$this->shop->view['arData'] = array();
			$this->shop->view['pages'] = 1;

			if (wpsg_isSizedArray($_REQUEST['filter']))
			{

				$_REQUEST['filter'] = wpsg_sinput("text_field", $_REQUEST['filter']);

				$this->shop->view['arFilter'] = $_REQUEST['filter'];
				$this->shop->view['hasFilter'] = true;

			}
			else if (wpsg_isSizedArray($_SESSION['wpsg']['backend']['customergroup']['arFilter'])) $this->shop->view['arFilter'] = $_SESSION['wpsg']['backend']['customergroup']['arFilter'];

			$this->shop->view['countAll'] = wpsg_customergroup::count($this->shop->view['arFilter']);

			if (wpsg_isSizedInt($_REQUEST['seite'])) $this->shop->view['arFilter']['page'] = $_REQUEST['seite'];

			$this->shop->view['pages'] = ceil($this->shop->view['countAll'] / $nPerPage);
			if ($this->shop->view['arFilter']['page'] <= 0 || $this->shop->view['arFilter']['page'] > $this->shop->view['pages']) $this->shop->view['arFilter']['page'] = 1;

			$this->shop->view['arFilter']['limit'] = array(($this->shop->view['arFilter']['page'] - 1) * $nPerPage, $nPerPage);

			// Filter speichern
			$_SESSION['wpsg']['backend']['customergroup']['arFilter'] = $this->shop->view['arFilter'];

			$this->shop->view['arData'] = wpsg_customergroup::find($this->shop->view['arFilter']);

			$this->shop->render(WPSG_PATH_VIEW.'mods/mod_customergroup/index.phtml');
 
		} // public function indexAction()
				
	} // class wpsg_mod_customergroup extends wpsg_mod_basic
	
?>